==> xmonad-contrib-0.13.20180518-3-x86_64.pkg.tar.xz: usr/share/haskell/register/xmonad-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad-contrib
version: 0.13
id: xmonad-contrib-0.13-HVVKqfPMbrVINvxVOVSQ6X
key: xmonad-contrib-0.13-HVVKqfPMbrVINvxVOVSQ6X
license: BSD-3-Clause
maintainer: xmonad@haskell.org
author: Spencer Janssen & others
homepage: http://xmonad.org/
synopsis: Third party extensions for xmonad
description:
    Third party tiling algorithms, configurations and scripts to xmonad,
    a tiling window manager for X.
    .
    For an introduction to building, configuring and using xmonad
    extensions, see "XMonad.Doc". In particular:
    .
    "XMonad.Doc.Configuring", a guide to configuring xmonad
    .
    "XMonad.Doc.Extending", using the contributed extensions library
    .
    "XMonad.Doc.Developing", introduction to xmonad internals and writing
    your own extensions.
    .
category: System
abi: c805d7d69ce11f9a4fa4c67fcb3ba4f7
exposed: True
exposed-modules:
    XMonad.Actions.AfterDrag XMonad.Actions.BluetileCommands
    XMonad.Actions.Commands XMonad.Actions.ConstrainedResize
    XMonad.Actions.CopyWindow XMonad.Actions.CycleRecentWS
    XMonad.Actions.CycleSelectedLayouts XMonad.Actions.CycleWS
    XMonad.Actions.CycleWindows XMonad.Actions.CycleWorkspaceByScreen
    XMonad.Actions.DeManage XMonad.Actions.DwmPromote
    XMonad.Actions.DynamicProjects
    XMonad.Actions.DynamicWorkspaceGroups
    XMonad.Actions.DynamicWorkspaceOrder
    XMonad.Actions.DynamicWorkspaces XMonad.Actions.FindEmptyWorkspace
    XMonad.Actions.FlexibleManipulate XMonad.Actions.FlexibleResize
    XMonad.Actions.FloatKeys XMonad.Actions.FloatSnap
    XMonad.Actions.FocusNth XMonad.Actions.GridSelect
    XMonad.Actions.GroupNavigation XMonad.Actions.KeyRemap
    XMonad.Actions.Launcher XMonad.Actions.LinkWorkspaces
    XMonad.Actions.MessageFeedback XMonad.Actions.Minimize
    XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
    XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
    XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
    XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
    XMonad.Actions.Promote XMonad.Actions.RandomBackground
    XMonad.Actions.RotSlaves XMonad.Actions.Search
    XMonad.Actions.ShowText XMonad.Actions.SimpleDate
    XMonad.Actions.SinkAll XMonad.Actions.SpawnOn XMonad.Actions.Submap
    XMonad.Actions.SwapWorkspaces XMonad.Actions.TagWindows
    XMonad.Actions.TopicSpace XMonad.Actions.TreeSelect
    XMonad.Actions.UpdateFocus XMonad.Actions.UpdatePointer
    XMonad.Actions.Warp XMonad.Actions.WindowBringer
    XMonad.Actions.WindowGo XMonad.Actions.WindowMenu
    XMonad.Actions.WindowNavigation XMonad.Actions.WithAll
    XMonad.Actions.Workscreen XMonad.Actions.WorkspaceCursors
    XMonad.Actions.WorkspaceNames XMonad.Config.Arossato
    XMonad.Config.Azerty XMonad.Config.Bepo XMonad.Config.Bluetile
    XMonad.Config.Desktop XMonad.Config.Dmwit XMonad.Config.Droundy
    XMonad.Config.Gnome XMonad.Config.Kde XMonad.Config.Mate
    XMonad.Config.Prime XMonad.Config.Sjanssen XMonad.Config.Xfce
    XMonad.Doc XMonad.Doc.Configuring XMonad.Doc.Developing
    XMonad.Doc.Extending XMonad.Hooks.CurrentWorkspaceOnTop
    XMonad.Hooks.DebugEvents XMonad.Hooks.DebugKeyEvents
    XMonad.Hooks.DebugStack XMonad.Hooks.DynamicBars
    XMonad.Hooks.DynamicHooks XMonad.Hooks.DynamicLog
    XMonad.Hooks.DynamicProperty XMonad.Hooks.EwmhDesktops
    XMonad.Hooks.FadeInactive XMonad.Hooks.FadeWindows
    XMonad.Hooks.FloatNext XMonad.Hooks.ICCCMFocus
    XMonad.Hooks.InsertPosition XMonad.Hooks.ManageDebug
    XMonad.Hooks.ManageDocks XMonad.Hooks.ManageHelpers
    XMonad.Hooks.Minimize XMonad.Hooks.Place
    XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RestoreMinimized
    XMonad.Hooks.ScreenCorners XMonad.Hooks.Script
    XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
    XMonad.Hooks.ToggleHook XMonad.Hooks.UrgencyHook
    XMonad.Hooks.WallpaperSetter XMonad.Hooks.WorkspaceByPos
    XMonad.Hooks.WorkspaceHistory XMonad.Hooks.XPropManage
    XMonad.Layout.Accordion XMonad.Layout.AutoMaster
    XMonad.Layout.AvoidFloats XMonad.Layout.BinarySpacePartition
    XMonad.Layout.BorderResize XMonad.Layout.BoringWindows
    XMonad.Layout.ButtonDecoration XMonad.Layout.CenteredMaster
    XMonad.Layout.Circle XMonad.Layout.Column XMonad.Layout.Combo
    XMonad.Layout.ComboP XMonad.Layout.Cross XMonad.Layout.Decoration
    XMonad.Layout.DecorationAddons XMonad.Layout.DecorationMadness
    XMonad.Layout.Dishes XMonad.Layout.DragPane
    XMonad.Layout.DraggingVisualizer XMonad.Layout.Drawer
    XMonad.Layout.Dwindle XMonad.Layout.DwmStyle
    XMonad.Layout.FixedColumn XMonad.Layout.Fullscreen
    XMonad.Layout.Gaps XMonad.Layout.Grid XMonad.Layout.GridVariants
    XMonad.Layout.Groups XMonad.Layout.Groups.Examples
    XMonad.Layout.Groups.Helpers XMonad.Layout.Groups.Wmii
    XMonad.Layout.Hidden XMonad.Layout.HintedGrid
    XMonad.Layout.HintedTile XMonad.Layout.IM XMonad.Layout.IfMax
    XMonad.Layout.ImageButtonDecoration
    XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
    XMonad.Layout.LayoutBuilderP XMonad.Layout.LayoutCombinators
    XMonad.Layout.LayoutHints XMonad.Layout.LayoutModifier
    XMonad.Layout.LayoutScreens XMonad.Layout.LimitWindows
    XMonad.Layout.MagicFocus XMonad.Layout.Magnifier
    XMonad.Layout.Master XMonad.Layout.Maximize
    XMonad.Layout.MessageControl XMonad.Layout.Minimize
    XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
    XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
    XMonad.Layout.MultiDishes XMonad.Layout.MultiToggle
    XMonad.Layout.MultiToggle.Instances XMonad.Layout.Named
    XMonad.Layout.NoBorders XMonad.Layout.NoFrillsDecoration
    XMonad.Layout.OnHost XMonad.Layout.OneBig XMonad.Layout.PerScreen
    XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
    XMonad.Layout.Reflect XMonad.Layout.Renamed
    XMonad.Layout.ResizableTile XMonad.Layout.ResizeScreen
    XMonad.Layout.Roledex XMonad.Layout.ShowWName
    XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
    XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
    XMonad.Layout.SortedLayout XMonad.Layout.Spacing
    XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
    XMonad.Layout.Stoppable XMonad.Layout.SubLayouts
    XMonad.Layout.TabBarDecoration XMonad.Layout.Tabbed
    XMonad.Layout.ThreeColumns XMonad.Layout.ToggleLayouts
    XMonad.Layout.TrackFloating XMonad.Layout.TwoPane
    XMonad.Layout.WindowArranger XMonad.Layout.WindowNavigation
    XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
    XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppLauncher
    XMonad.Prompt.AppendFile XMonad.Prompt.ConfirmPrompt
    XMonad.Prompt.DirExec XMonad.Prompt.Directory XMonad.Prompt.Email
    XMonad.Prompt.FuzzyMatch XMonad.Prompt.Input XMonad.Prompt.Layout
    XMonad.Prompt.Man XMonad.Prompt.Pass XMonad.Prompt.RunOrRaise
    XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
    XMonad.Prompt.Unicode XMonad.Prompt.Window XMonad.Prompt.Workspace
    XMonad.Prompt.XMonad XMonad.Util.Cursor XMonad.Util.CustomKeys
    XMonad.Util.DebugWindow XMonad.Util.Dmenu XMonad.Util.Dzen
    XMonad.Util.EZConfig XMonad.Util.ExtensibleState XMonad.Util.Font
    XMonad.Util.Image XMonad.Util.Invisible XMonad.Util.Loggers
    XMonad.Util.Loggers.NamedScratchpad XMonad.Util.Minimize
    XMonad.Util.NamedActions XMonad.Util.NamedScratchpad
    XMonad.Util.NamedWindows XMonad.Util.NoTaskbar XMonad.Util.Paste
    XMonad.Util.PositionStore XMonad.Util.RemoteWindows
    XMonad.Util.Replace XMonad.Util.Run XMonad.Util.Scratchpad
    XMonad.Util.SessionStart XMonad.Util.SpawnNamedPipe
    XMonad.Util.SpawnOnce XMonad.Util.Stack XMonad.Util.StringProp
    XMonad.Util.Themes XMonad.Util.Timer XMonad.Util.TreeZipper
    XMonad.Util.Types XMonad.Util.Ungrab XMonad.Util.WindowProperties
    XMonad.Util.WindowState XMonad.Util.WorkspaceCompare
    XMonad.Util.XSelection XMonad.Util.XUtils
import-dirs: /usr/lib/ghc-8.4.3/site-local/xmonad-contrib-0.13
library-dirs: /usr/lib/ghc-8.4.3/site-local/xmonad-contrib-0.13
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.4.3
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/xmonad-contrib-0.13
hs-libraries: HSxmonad-contrib-0.13-HVVKqfPMbrVINvxVOVSQ6X
depends:
    X11-1.8-2GHfNeKQbxBLmODzL3h52l X11-xft-0.3.1-6yn4Mn0GaIL5FnhdB6WPd2
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn filepath-1.4.2
    mtl-2.2.2 old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu process-1.6.3.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV unix-2.7.2.2
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    xmonad-0.13-Intl7psvCrCEwGJXN7atYm
abi-depends: X11-1.8-2GHfNeKQbxBLmODzL3h52l=e42fc8f90fd0f132c1dc5712a1c8a0c8
             X11-xft-0.3.1-6yn4Mn0GaIL5FnhdB6WPd2=5d1cc28ad5219670d4029c34d680373a
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=bad6d8216f3724a304dcc80fb49d8538
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             xmonad-0.13-Intl7psvCrCEwGJXN7atYm=a3069b3f409202797ab26f937d4b26aa
haddock-interfaces: /usr/share/doc/xmonad-contrib/html/xmonad-contrib.haddock
haddock-html: /usr/share/doc/xmonad-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-contrib-0.14-2-x86_64.pkg.tar.xz: usr/share/haskell/register/xmonad-contrib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad-contrib
version: 0.14
id: xmonad-contrib-0.14-GcTFiVsRQSVEdBwtNWPPbo
key: xmonad-contrib-0.14-GcTFiVsRQSVEdBwtNWPPbo
license: BSD-3-Clause
maintainer: xmonad@haskell.org
author: Spencer Janssen & others
homepage: http://xmonad.org/
synopsis: Third party extensions for xmonad
description:
    Third party tiling algorithms, configurations and scripts to xmonad,
    a tiling window manager for X.
    .
    For an introduction to building, configuring and using xmonad
    extensions, see "XMonad.Doc". In particular:
    .
    "XMonad.Doc.Configuring", a guide to configuring xmonad
    .
    "XMonad.Doc.Extending", using the contributed extensions library
    .
    "XMonad.Doc.Developing", introduction to xmonad internals and writing
    your own extensions.
    .
category: System
abi: 137fd552825c2fd6acbf239c02f28ea5
exposed: True
exposed-modules:
    XMonad.Actions.AfterDrag XMonad.Actions.BluetileCommands
    XMonad.Actions.Commands XMonad.Actions.ConstrainedResize
    XMonad.Actions.CopyWindow XMonad.Actions.CycleRecentWS
    XMonad.Actions.CycleSelectedLayouts XMonad.Actions.CycleWS
    XMonad.Actions.CycleWindows XMonad.Actions.CycleWorkspaceByScreen
    XMonad.Actions.DeManage XMonad.Actions.DwmPromote
    XMonad.Actions.DynamicProjects
    XMonad.Actions.DynamicWorkspaceGroups
    XMonad.Actions.DynamicWorkspaceOrder
    XMonad.Actions.DynamicWorkspaces XMonad.Actions.FindEmptyWorkspace
    XMonad.Actions.FlexibleManipulate XMonad.Actions.FlexibleResize
    XMonad.Actions.FloatKeys XMonad.Actions.FloatSnap
    XMonad.Actions.FocusNth XMonad.Actions.GridSelect
    XMonad.Actions.GroupNavigation XMonad.Actions.KeyRemap
    XMonad.Actions.Launcher XMonad.Actions.LinkWorkspaces
    XMonad.Actions.MessageFeedback XMonad.Actions.Minimize
    XMonad.Actions.MouseGestures XMonad.Actions.MouseResize
    XMonad.Actions.Navigation2D XMonad.Actions.NoBorders
    XMonad.Actions.OnScreen XMonad.Actions.PerWorkspaceKeys
    XMonad.Actions.PhysicalScreens XMonad.Actions.Plane
    XMonad.Actions.Promote XMonad.Actions.RandomBackground
    XMonad.Actions.RotSlaves XMonad.Actions.Search
    XMonad.Actions.ShowText XMonad.Actions.SimpleDate
    XMonad.Actions.SinkAll XMonad.Actions.SpawnOn XMonad.Actions.Submap
    XMonad.Actions.SwapPromote XMonad.Actions.SwapWorkspaces
    XMonad.Actions.TagWindows XMonad.Actions.TopicSpace
    XMonad.Actions.TreeSelect XMonad.Actions.UpdateFocus
    XMonad.Actions.UpdatePointer XMonad.Actions.Warp
    XMonad.Actions.WindowBringer XMonad.Actions.WindowGo
    XMonad.Actions.WindowMenu XMonad.Actions.WindowNavigation
    XMonad.Actions.WithAll XMonad.Actions.Workscreen
    XMonad.Actions.WorkspaceCursors XMonad.Actions.WorkspaceNames
    XMonad.Config.Arossato XMonad.Config.Azerty XMonad.Config.Bepo
    XMonad.Config.Bluetile XMonad.Config.Desktop XMonad.Config.Dmwit
    XMonad.Config.Droundy XMonad.Config.Gnome XMonad.Config.Kde
    XMonad.Config.Mate XMonad.Config.Prime XMonad.Config.Sjanssen
    XMonad.Config.Xfce XMonad.Doc XMonad.Doc.Configuring
    XMonad.Doc.Developing XMonad.Doc.Extending
    XMonad.Hooks.CurrentWorkspaceOnTop XMonad.Hooks.DebugEvents
    XMonad.Hooks.DebugKeyEvents XMonad.Hooks.DebugStack
    XMonad.Hooks.DynamicBars XMonad.Hooks.DynamicHooks
    XMonad.Hooks.DynamicLog XMonad.Hooks.DynamicProperty
    XMonad.Hooks.EwmhDesktops XMonad.Hooks.FadeInactive
    XMonad.Hooks.FadeWindows XMonad.Hooks.FloatNext
    XMonad.Hooks.ICCCMFocus XMonad.Hooks.InsertPosition
    XMonad.Hooks.ManageDebug XMonad.Hooks.ManageDocks
    XMonad.Hooks.ManageHelpers XMonad.Hooks.Minimize XMonad.Hooks.Place
    XMonad.Hooks.PositionStoreHooks XMonad.Hooks.RestoreMinimized
    XMonad.Hooks.ScreenCorners XMonad.Hooks.Script
    XMonad.Hooks.ServerMode XMonad.Hooks.SetWMName
    XMonad.Hooks.ToggleHook XMonad.Hooks.UrgencyHook
    XMonad.Hooks.WallpaperSetter XMonad.Hooks.WorkspaceByPos
    XMonad.Hooks.WorkspaceHistory XMonad.Hooks.XPropManage
    XMonad.Layout.Accordion XMonad.Layout.AutoMaster
    XMonad.Layout.AvoidFloats XMonad.Layout.BinaryColumn
    XMonad.Layout.BinarySpacePartition XMonad.Layout.BorderResize
    XMonad.Layout.BoringWindows XMonad.Layout.ButtonDecoration
    XMonad.Layout.CenteredMaster XMonad.Layout.Circle
    XMonad.Layout.Column XMonad.Layout.Combo XMonad.Layout.ComboP
    XMonad.Layout.Cross XMonad.Layout.Decoration
    XMonad.Layout.DecorationAddons XMonad.Layout.DecorationMadness
    XMonad.Layout.Dishes XMonad.Layout.DragPane
    XMonad.Layout.DraggingVisualizer XMonad.Layout.Drawer
    XMonad.Layout.Dwindle XMonad.Layout.DwmStyle
    XMonad.Layout.FixedColumn XMonad.Layout.Fullscreen
    XMonad.Layout.Gaps XMonad.Layout.Grid XMonad.Layout.GridVariants
    XMonad.Layout.Groups XMonad.Layout.Groups.Examples
    XMonad.Layout.Groups.Helpers XMonad.Layout.Groups.Wmii
    XMonad.Layout.Hidden XMonad.Layout.HintedGrid
    XMonad.Layout.HintedTile XMonad.Layout.IM XMonad.Layout.IfMax
    XMonad.Layout.ImageButtonDecoration
    XMonad.Layout.IndependentScreens XMonad.Layout.LayoutBuilder
    XMonad.Layout.LayoutBuilderP XMonad.Layout.LayoutCombinators
    XMonad.Layout.LayoutHints XMonad.Layout.LayoutModifier
    XMonad.Layout.LayoutScreens XMonad.Layout.LimitWindows
    XMonad.Layout.MagicFocus XMonad.Layout.Magnifier
    XMonad.Layout.Master XMonad.Layout.Maximize
    XMonad.Layout.MessageControl XMonad.Layout.Minimize
    XMonad.Layout.Monitor XMonad.Layout.Mosaic XMonad.Layout.MosaicAlt
    XMonad.Layout.MouseResizableTile XMonad.Layout.MultiColumns
    XMonad.Layout.MultiDishes XMonad.Layout.MultiToggle
    XMonad.Layout.MultiToggle.Instances
    XMonad.Layout.MultiToggle.TabBarDecoration XMonad.Layout.Named
    XMonad.Layout.NoBorders XMonad.Layout.NoFrillsDecoration
    XMonad.Layout.OnHost XMonad.Layout.OneBig XMonad.Layout.PerScreen
    XMonad.Layout.PerWorkspace XMonad.Layout.PositionStoreFloat
    XMonad.Layout.Reflect XMonad.Layout.Renamed
    XMonad.Layout.ResizableTile XMonad.Layout.ResizeScreen
    XMonad.Layout.Roledex XMonad.Layout.ShowWName
    XMonad.Layout.SimpleDecoration XMonad.Layout.SimpleFloat
    XMonad.Layout.Simplest XMonad.Layout.SimplestFloat
    XMonad.Layout.SortedLayout XMonad.Layout.Spacing
    XMonad.Layout.Spiral XMonad.Layout.Square XMonad.Layout.StackTile
    XMonad.Layout.StateFull XMonad.Layout.Stoppable
    XMonad.Layout.SubLayouts XMonad.Layout.TabBarDecoration
    XMonad.Layout.Tabbed XMonad.Layout.ThreeColumns
    XMonad.Layout.ToggleLayouts XMonad.Layout.TrackFloating
    XMonad.Layout.TwoPane XMonad.Layout.WindowArranger
    XMonad.Layout.WindowNavigation
    XMonad.Layout.WindowSwitcherDecoration XMonad.Layout.WorkspaceDir
    XMonad.Layout.ZoomRow XMonad.Prompt XMonad.Prompt.AppLauncher
    XMonad.Prompt.AppendFile XMonad.Prompt.ConfirmPrompt
    XMonad.Prompt.DirExec XMonad.Prompt.Directory XMonad.Prompt.Email
    XMonad.Prompt.FuzzyMatch XMonad.Prompt.Input XMonad.Prompt.Layout
    XMonad.Prompt.Man XMonad.Prompt.Pass XMonad.Prompt.RunOrRaise
    XMonad.Prompt.Shell XMonad.Prompt.Ssh XMonad.Prompt.Theme
    XMonad.Prompt.Unicode XMonad.Prompt.Window XMonad.Prompt.Workspace
    XMonad.Prompt.XMonad XMonad.Util.Cursor XMonad.Util.CustomKeys
    XMonad.Util.DebugWindow XMonad.Util.Dmenu XMonad.Util.Dzen
    XMonad.Util.EZConfig XMonad.Util.ExtensibleState XMonad.Util.Font
    XMonad.Util.Image XMonad.Util.Invisible XMonad.Util.Loggers
    XMonad.Util.Loggers.NamedScratchpad XMonad.Util.Minimize
    XMonad.Util.NamedActions XMonad.Util.NamedScratchpad
    XMonad.Util.NamedWindows XMonad.Util.NoTaskbar XMonad.Util.Paste
    XMonad.Util.PositionStore XMonad.Util.Rectangle
    XMonad.Util.RemoteWindows XMonad.Util.Replace XMonad.Util.Run
    XMonad.Util.Scratchpad XMonad.Util.SessionStart
    XMonad.Util.SpawnNamedPipe XMonad.Util.SpawnOnce XMonad.Util.Stack
    XMonad.Util.StringProp XMonad.Util.Themes XMonad.Util.Timer
    XMonad.Util.TreeZipper XMonad.Util.Types XMonad.Util.Ungrab
    XMonad.Util.WindowProperties XMonad.Util.WindowState
    XMonad.Util.WorkspaceCompare XMonad.Util.XSelection
    XMonad.Util.XUtils
import-dirs: /usr/lib/ghc-8.4.3/site-local/xmonad-contrib-0.14
library-dirs: /usr/lib/ghc-8.4.3/site-local/xmonad-contrib-0.14
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.4.3
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/xmonad-contrib-0.14
hs-libraries: HSxmonad-contrib-0.14-GcTFiVsRQSVEdBwtNWPPbo
depends:
    X11-1.8-2GHfNeKQbxBLmODzL3h52l X11-xft-0.3.1-6yn4Mn0GaIL5FnhdB6WPd2
    base-4.11.1.0 bytestring-0.10.8.2 containers-0.5.11.0
    directory-1.3.1.5
    extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn filepath-1.4.2
    mtl-2.2.2 old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu process-1.6.3.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV unix-2.7.2.2
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
    xmonad-0.14-3SWKkh0YU4b3S94g79h7Ve
abi-depends: X11-1.8-2GHfNeKQbxBLmODzL3h52l=e42fc8f90fd0f132c1dc5712a1c8a0c8
             X11-xft-0.3.1-6yn4Mn0GaIL5FnhdB6WPd2=5d1cc28ad5219670d4029c34d680373a
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             extensible-exceptions-0.1.1.4-J1OT5xNWUKn5hZNwjN7aJn=bad6d8216f3724a304dcc80fb49d8538
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             old-locale-1.0.0.7-26K7wLFR2jK44UeOklvTCh=624bb9fc159afd36b39208b6844f8edd
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
             xmonad-0.14-3SWKkh0YU4b3S94g79h7Ve=8b2e1fb9bc4e5d42ff07f8a47301aa16
haddock-interfaces: /usr/share/doc/xmonad-contrib/html/xmonad-contrib.haddock
haddock-html: /usr/share/doc/xmonad-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
